#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""AIS Cursor-On-Target Constants."""

import logging
import os
import pkg_resources

__author__ = "Greg Albrecht W2GMD <oss@undef.net>"
__copyright__ = "Copyright 2021 Greg Albrecht"
__license__ = "Apache License, Version 2.0"


if bool(os.environ.get("DEBUG")):
    LOG_LEVEL = logging.DEBUG
    LOG_FORMAT = logging.Formatter(
        (
            "%(asctime)s aiscot %(levelname)s %(name)s.%(funcName)s:%(lineno)d "
            " - %(message)s"
        )
    )
    logging.debug("aiscot Debugging Enabled via DEBUG Environment Variable.")
else:
    LOG_LEVEL = logging.INFO
    LOG_FORMAT = logging.Formatter(("%(asctime)s aiscot %(levelname)s - %(message)s"))

DEFAULT_AIS_PORT: int = 5050
DEFAULT_COT_STALE: int = 3600  # 1 hour
DEFAULT_COT_TYPE: str = "a-u-S-X-M"
DEFAULT_POLL_INTERVAL: int = 61
DEFAULT_COT_URL: str = "udp://239.2.3.1:6969"  # ATAK Default multicast

MID_DB_FILE = os.getenv(
    "MID_DB_FILE",
    pkg_resources.resource_filename(
        __name__,
        "data/MaritimeIdentificationDigits-bb62983a-cf0e-40a1-9431-cd54eaeb1c85.csv",
    ),
)
SHIP_DB_FILE = os.getenv(
    "SHIP_DB_FILE",
    pkg_resources.resource_filename(
        __name__, "data/yadd_mmsi_ship_2021-11-03-170131.txt"
    ),
)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""AIS Cursor-On-Target Class Definitions."""

import asyncio
import configparser
import logging
import urllib

import aiohttp
import pytak

import aiscot

import aiscot.pyAISm

__author__ = "Greg Albrecht W2GMD <oss@undef.net>"
__copyright__ = "Copyright 2022 Greg Albrecht"
__license__ = "Apache License, Version 2.0"


# pylint: disable=too-many-instance-attributes
class AISNetworkClient(asyncio.Protocol):

    """Class for handling connections from network AIS feed."""

    _logger = logging.getLogger(__name__)
    if not _logger.handlers:
        _logger.setLevel(aiscot.LOG_LEVEL)
        _console_handler = logging.StreamHandler()
        _console_handler.setLevel(aiscot.LOG_LEVEL)
        _console_handler.setFormatter(aiscot.LOG_FORMAT)
        _logger.addHandler(_console_handler)
        _logger.propagate = False
    logging.getLogger("asyncio").setLevel(aiscot.LOG_LEVEL)

    def __init__(self, ready, event_queue, opts) -> None:
        self.transport = None
        self.address = None

        self.ready = ready
        self.event_queue = event_queue

        self.cot_stale = opts.get("COT_STALE")
        self.cot_type = opts.get("COT_TYPE")

        self.include_all_craft = bool(opts.get("INCLUDE_ALL_CRAFT")) or False

        self.filters = opts.get("FILTERS")
        self.known_craft = opts.get("KNOWN_CRAFT")
        self.known_craft_key = opts.get("KNOWN_CRAFT_KEY") or "MMSI"

        self.filter_type = ""
        self.known_craft_db = None

    def handle_message(self, data) -> None:
        """Handles incoming AIS data from network."""
        d_data = data.decode().strip()
        msg = aiscot.pyAISm.decod_ais(d_data)

        # self._logger.info("Received AIS: '%s'", msg)

        mmsi = str(msg.get("mmsi"))

        known_craft = {}

        if self.filter_type:
            if self.filter_type == "MMSI":
                filter_key: str = str(mmsi)
            else:
                filter_key: str = ""

            # self._logger.debug("filter_key=%s", filter_key)

            if self.known_craft_db and filter_key:
                known_craft = (
                    list(
                        filter(
                            lambda x: x[self.known_craft_key].strip().upper()
                            == filter_key,
                            self.known_craft_db,
                        )
                    )
                    or [{}]
                )[0]
                # self._logger.debug("known_craft='%s'", known_craft)
            elif filter_key:
                if "include" in self.filters[
                    self.filter_type
                ] and filter_key not in self.filters.get(self.filter_type, "include"):
                    return
                if "exclude" in self.filters[
                    self.filter_type
                ] and filter_key in self.filters.get(self.filter_type, "exclude"):
                    return

        # If we're using a known_craft csv and this craft wasn't found, skip:
        if self.known_craft_db and not known_craft and not self.include_all_craft:
            return

        event: str = aiscot.ais_to_cot(
            msg, stale=self.cot_stale, cot_type=self.cot_type, known_craft=known_craft
        )

        if event:
            self.event_queue.put_nowait(event)

    def connection_made(self, transport):
        """Called when a network connection is made."""
        self.transport = transport
        self.address = transport.get_extra_info("peername")
        self._logger.debug("Connection from %s", self.address)

        if self.known_craft is not None:
            self._logger.info("Using KNOWN_CRAFT File: '%s'", self.known_craft)
            self.known_craft_db = aiscot.read_known_craft(self.known_craft)
            self.filters = configparser.ConfigParser()
            self.filters.add_section(self.known_craft_key)
            self.filters[self.known_craft_key]["include"] = str(
                [x[self.known_craft_key].strip().upper() for x in self.known_craft_db]
            )

        if self.filters or self.known_craft_db:
            filter_src = self.filters or self.known_craft_key
            self._logger.debug("filter_src=%s", filter_src)
            if filter_src:
                if "MMSI" in filter_src:
                    self.filter_type = "MMSI"
                self._logger.debug("filter_type=%s", self.filter_type)

        self.ready.set()

    def datagram_received(self, data, addr):
        """Called when a UDP datagram is received."""
        self._logger.debug("Recieved from %s: '%s'", addr, data)
        for line in data.splitlines():
            self.handle_message(line)

    def connection_lost(self, exc):
        """Called when a network connection is lost."""
        self.ready.clear()
        self._logger.exception(exc)
        self._logger.warning("Disconnected from %s", self.address)


class AISWorker(pytak.MessageWorker):

    """AIS Cursor-on-Target Class."""

    def __init__(self, event_queue: asyncio.Queue, config) -> None:
        super().__init__(event_queue)

        self.config = config["aiscot"]

        aishub_url = self.config.get("AISHUB_URL")
        if aishub_url:
            self.aishub_url: urllib.parse.ParseResult = urllib.parse.urlparse(
                aishub_url
            )
        else:
            self.aishub_url = None

        self.cot_stale = self.config.get("COT_STALE")
        self.cot_type = self.config.get("COT_TYPE")
        self.poll_interval: int = int(
            self.config.get("POLL_INTERVAL") or aiscot.DEFAULT_POLL_INTERVAL
        )

        self.include_all_craft = bool(self.config.get("INCLUDE_ALL_CRAFT")) or False

        self.filters = self.config.get("FILTERS")
        self.known_craft = self.config.get("KNOWN_CRAFT")
        self.known_craft_key = self.config.get("KNOWN_CRAFT_KEY") or "MMSI"

        self.filter_type = ""
        self.known_craft_db = None

        self.ais_port = int(self.config.get("AIS_PORT") or aiscot.DEFAULT_AIS_PORT)
        self.listen_host = self.config.get("LISTEN_HOST") or "0.0.0.0"

    async def handle_message(self, msgs) -> None:
        """Handles received MMSI data."""
        # self._logger.info("Received AIS: '%s'", msg)

        for msg in msgs:
            mmsi = str(msg.get("MMSI"))

            known_craft = {}

            if self.filter_type:
                if self.filter_type == "MMSI":
                    filter_key: str = str(mmsi)
                else:
                    filter_key: str = ""

                # self._logger.info("filter_key=%s", filter_key)

                if self.known_craft_db and filter_key:
                    known_craft = (
                        list(
                            filter(
                                lambda x: x[self.known_craft_key].strip().upper()
                                == filter_key,
                                self.known_craft_db,
                            )
                        )
                        or [{}]
                    )[0]
                    # self._logger.debug("known_craft='%s'", known_craft)
                elif filter_key:
                    if "include" in self.filters[
                        self.filter_type
                    ] and filter_key not in self.filters.get(
                        self.filter_type, "include"
                    ):
                        return
                    if "exclude" in self.filters[
                        self.filter_type
                    ] and filter_key in self.filters.get(self.filter_type, "exclude"):
                        return

            # If we're using a known_craft csv and this craft wasn't found, skip:
            if self.known_craft_db and not known_craft and not self.include_all_craft:
                return

            event: str = aiscot.ais_to_cot(
                msg,
                stale=self.cot_stale,
                cot_type=self.cot_type,
                known_craft=known_craft,
            )
            await self._put_event_queue(event)

    async def _get_aishub_feed(self):
        """
        Gets AIS data from AISHub feed.
        """
        feed_url: str = self.aishub_url.geturl()
        self._logger.info("Getting feed from %s", feed_url)

        async with aiohttp.ClientSession() as session:
            response = await session.request(method="GET", url=feed_url)
            response.raise_for_status()
            json_resp = await response.json()

            api_report = json_resp[0]
            if api_report.get("ERROR"):
                self._logger.error("AISHub.com API returned an error: ")
                self._logger.error(api_report)
            else:
                ships = json_resp[1]
                self._logger.debug("Retrieved %s ships", len(ships))
                await self.handle_message(ships)

    async def run(self, number_of_iterations=-1):
        """Runs this Thread, reads AIS & outputs CoT."""
        self._logger.info("Running AISWorker")
        loop = asyncio.get_event_loop()

        if self.aishub_url:
            if self.known_craft is not None:
                self._logger.info("Using KNOWN_CRAFT File: '%s'", self.known_craft)
                self.known_craft_db = aiscot.read_known_craft(self.known_craft)
                self.filters = configparser.ConfigParser()
                self.filters.add_section(self.known_craft_key)
                self.filters[self.known_craft_key]["include"] = str(
                    [
                        x[self.known_craft_key].strip().upper()
                        for x in self.known_craft_db
                    ]
                )

            if self.filters or self.known_craft_db:
                filter_src = self.filters or self.known_craft_key
                self._logger.debug("filter_src=%s", filter_src)
                if filter_src:
                    if "MMSI" in filter_src:
                        self.filter_type = "MMSI"
                    self._logger.debug("filter_type=%s", self.filter_type)
        else:
            ready = asyncio.Event()
            await loop.create_datagram_endpoint(
                lambda: AISNetworkClient(ready, self.event_queue, self.config),
                local_addr=(self.listen_host, self.ais_port),
            )

            await ready.wait()

        while 1:
            if self.aishub_url:
                await self._get_aishub_feed()
            await asyncio.sleep(self.poll_interval)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# AIS Cursor-On-Target Gateway.

"""
AIS Cursor-On-Target Gateway.
~~~~


:author: Greg Albrecht W2GMD <oss@undef.net>
:copyright: Copyright 2022 Greg Albrecht
:license: Apache License, Version 2.0
:source: <https://github.com/ampledata/aiscot>

"""

from .constants import (  # NOQA
    LOG_FORMAT,
    LOG_LEVEL,
    DEFAULT_AIS_PORT,
    DEFAULT_COT_TYPE,
    DEFAULT_COT_STALE,
    DEFAULT_POLL_INTERVAL,
    MID_DB_FILE,
    SHIP_DB_FILE,
    DEFAULT_COT_URL,
)

from .functions import (  # NOQA
    ais_to_cot,
    read_known_craft,
    get_mid,
    get_aton,
    get_sar,
    get_crs,
    get_shipname,
    ais_to_cot_xml,
)

from .classes import AISWorker  # NOQA

__author__ = "Greg Albrecht W2GMD <oss@undef.net>"
__copyright__ = "Copyright 2022 Greg Albrecht"
__license__ = "Apache License, Version 2.0"



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""AIS Cursor-On-Target Gateway Commands."""

import argparse
import asyncio
import configparser
import logging
import os
import sys

from urllib.parse import urlparse, ParseResult

import pytak

import aiscot

# Python 3.6 support:
if sys.version_info[:2] >= (3, 7):
    from asyncio import get_running_loop
else:
    from asyncio import (  # pylint: disable=no-name-in-module
        _get_running_loop as get_running_loop,
    )


__author__ = "Greg Albrecht W2GMD <oss@undef.net>"
__copyright__ = "Copyright 2022 Greg Albrecht"
__license__ = "Apache License, Version 2.0"


async def main(config):
    """Main program function."""
    tx_queue: asyncio.Queue = asyncio.Queue()
    rx_queue: asyncio.Queue = asyncio.Queue()
    cot_url: ParseResult = urlparse(config["aiscot"].get("COT_URL"))

    # Create our CoT Event Queue Worker
    reader, writer = await pytak.protocol_factory(cot_url)
    write_worker = pytak.EventTransmitter(tx_queue, writer)
    read_worker = pytak.EventReceiver(rx_queue, reader)

    message_worker = aiscot.AISWorker(tx_queue, config)

    await tx_queue.put(pytak.hello_event("aiscot"))

    done, _ = await asyncio.wait(
        set([message_worker.run(), read_worker.run(), write_worker.run()]),
        return_when=asyncio.FIRST_COMPLETED,
    )

    for task in done:
        print(f"Task completed: {task}")


def cli():
    """Command Line interface for AIS Cursor-on-Target Gateway."""

    parser = argparse.ArgumentParser()
    parser.add_argument(
        "-c", "--CONFIG_FILE", dest="CONFIG_FILE", default="config.ini", type=str
    )
    namespace = parser.parse_args()
    cli_args = {k: v for k, v in vars(namespace).items() if v is not None}

    # Read config:
    env_vars = os.environ
    env_vars["COT_URL"] = env_vars.get("COT_URL", aiscot.DEFAULT_COT_URL)
    config = configparser.ConfigParser(env_vars)
    config_file = cli_args.get("CONFIG_FILE")
    logging.info("Reading configuration from %s", config_file)
    config.read(config_file)

    if sys.version_info[:2] >= (3, 7):
        asyncio.run(main(config), debug=config["aiscot"].getboolean("DEBUG"))
    else:
        loop = get_running_loop()
        try:
            loop.run_until_complete(main(config))
        finally:
            loop.close()


if __name__ == "__main__":
    cli()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""AIS Cursor-On-Target Gateway Functions."""

import csv
import datetime
import platform

import xml.etree.ElementTree as ET

import pytak

import aiscot

__author__ = "Greg Albrecht W2GMD <oss@undef.net>"
__copyright__ = "Copyright 2022 Greg Albrecht"
__license__ = "Apache License, Version 2.0"


# pylint: disable=too-many-locals, too-many-branches, too-many-statements
def ais_to_cot_xml(
    msg: dict, stale: int = None, cot_type: str = "", known_craft: dict = None
) -> ET.Element:
    """
    Converts an AIS Sentence to a Cursor-On-Target Event.

    :param msg: AIS Sentence to convert to COT.
    :type msg: `dict`
    :param cot_stale: Number of Seconds from now to mark the COT Event stale.
    :type cot_stale: `int`
    """
    known_craft = known_craft or {}
    time = datetime.datetime.now(datetime.timezone.utc)

    cot_stale = stale or known_craft.get("STALE") or aiscot.DEFAULT_COT_STALE

    mmsi = msg.get("mmsi", msg.get("MMSI"))

    ais_name: str = msg.get("name", msg.get("NAME", "")).replace("@", "").strip()
    shipname: str = msg.get("shipname", aiscot.get_shipname(mmsi))

    if shipname:
        ais_name = shipname

    name = f"MMSI-{mmsi}"
    _name = known_craft.get("NAME") or ais_name
    if _name:
        callsign = _name
    else:
        callsign = mmsi

    if known_craft.get("NAME"):
        print(f"NAME = {_name} MMSI = {mmsi}")

    cot_type = known_craft.get("COT") or cot_type or aiscot.DEFAULT_COT_TYPE

    country: str = aiscot.get_mid(mmsi)
    if country and "United States of America" in country:
        cot_type = "a-f" + cot_type[3:]
    elif country:
        cot_type = "a-n" + cot_type[3:]

    aton: bool = aiscot.get_aton(mmsi)
    if aton:
        cot_type = "a-n-S-N"
        cot_stale = 86400  # 1 Day
        callsign = f"AtoN {callsign}"

    uscg: bool = aiscot.get_sar(mmsi)
    if uscg:
        cot_type = "a-f-S-X-L"

    crs: bool = aiscot.get_crs(mmsi)
    if crs:
        cot_type = "a-f-G-I-U-T"
        cot_stale = 86400  # 1 Day
        callsign = f"USCG CRS {callsign}"

    point = ET.Element("point")
    point.set("lat", str(msg.get("lat", msg.get("LATITUDE"))))
    point.set("lon", str(msg.get("lon", msg.get("LONGITUDE"))))
    point.set("hae", "9999999.0")
    point.set("le", "9999999.0")
    point.set("ce", "9999999.0")

    contact = ET.Element("contact")
    contact.set("callsign", str(callsign))

    track = ET.Element("track")
    track.set("course", str(msg.get("heading", msg.get("HEADING", 0))))

    # Speed over ground: 0.1-knot (0.19 km/h) resolution from
    #                    0 to 102 knots (189 km/h)
    sog = int(msg.get("speed", msg.get("SPEED", 0)))
    if sog:
        track.set("speed", str(sog * 0.514444))
    else:
        track.set("speed", "9999999.0")

    detail = ET.Element("detail")
    detail.set("uid", name)
    detail.append(contact)
    detail.append(track)

    remarks = ET.Element("remarks")

    if crs:
        remark = f"USCG CRS {mmsi}"
        if ais_name:
            remark = f"USCG CRS {ais_name} {mmsi}"
    else:
        _remark = f"AtoN/{aton} MMSI/{mmsi} Co/{country}"
        if ais_name:
            remark = f"{ais_name} {_remark}"
        else:
            remark = _remark

    _remarks = f"{remark} Ty/{msg.get('type', msg.get('TYPE'))} Sn/{shipname}"
    remarks.text = f"{_remarks} aiscot@{platform.node()}"
    detail.append(remarks)

    root = ET.Element("event")

    root.set("version", "2.0")
    root.set("type", cot_type)
    root.set("uid", name)
    root.set("how", "m-g")
    root.set("time", time.strftime(pytak.ISO_8601_UTC))
    root.set("start", time.strftime(pytak.ISO_8601_UTC))
    root.set(
        "stale",
        (time + datetime.timedelta(seconds=int(cot_stale))).strftime(
            pytak.ISO_8601_UTC
        ),
    )

    root.append(point)
    root.append(detail)

    return root


def ais_to_cot(
    ais_msg: dict, stale: int = None, cot_type: str = "", known_craft: dict = None
) -> str:
    """
    Converts an AIS Sentence to a Cursor-on-Target Event as a Python `str` String.

    See `ais_to_cot_xml()` for XML Object output version of this function.

    :param ais_msg: AIS Sentence to convert to CoT.
    :type ais_msg: `dict`
    :param cot_stale: Number of Seconds from now to mark the CoT Event stale.
    :type cot_stale: `int`
    """
    lat = ais_msg.get("lat")
    lon = ais_msg.get("lon")
    mmsi = ais_msg.get("mmsi")

    if lat is None or lon is None or mmsi is None:
        return None

    return ET.tostring(ais_to_cot_xml(ais_msg, stale, cot_type, known_craft))


def _read_known_craft_fd(csv_fd) -> list:
    """Reads known craft file into an iterable key=value array.

    Parameters
    ----------
    csv_fd : `fd`
        FD Object.

    Returns
    -------
    `list`
        Rows of `dict`s of CSV FD.
    """
    all_rows: list = []
    reader = csv.DictReader(csv_fd)
    for row in reader:
        all_rows.append(row)
    return all_rows


def read_known_craft(csv_file: str) -> list:
    """Reads Known Craft file into an iterable key=value array.

    Parameters
    ----------
    csv_file : `str`
        Path to the Known Craft CSV file.

    Returns
    -------
    `list`
        Rows of `dict`s of Known Crafts.
    """
    all_rows: list = []
    with open(csv_file) as csv_fd:
        all_rows = _read_known_craft_fd(csv_fd)
    return all_rows


def read_mid_db_file(csv_file: str = aiscot.MID_DB_FILE) -> list:
    """Reads the MID_DB_FILE file into a `dict`"""
    mid_digits: list = []
    mid_allocated_to: list = []

    with open(csv_file) as csv_fd:
        reader = csv.DictReader(csv_fd)
        for row in reader:
            mid_digits.append(row["Digit"])
            mid_allocated_to.append(row["Allocated to"])

    return dict(zip(mid_digits, mid_allocated_to))


def read_ship_db_file(csv_file: str = aiscot.SHIP_DB_FILE) -> list:
    """Reads the SHIP_DB_FILE file into a `list`"""
    all_rows: list = []
    fields: list = ["MMSI", "name", "unk", "vtype"]
    with open(csv_file, "r", encoding="ISO-8859-1") as csv_fd:
        reader = csv.DictReader(csv_fd, fields)
        for row in reader:
            all_rows.append(row)
        return all_rows


MID_DB = read_mid_db_file()
SHIP_DB = read_ship_db_file()


def get_mid(mmsi: str) -> str:
    """
    Gets the registered country for a given vessel's MMSI MID.

    Uses the ITU MID Database.

    TK URL to ITU DB.

    Parameters
    ----------
    mmsi : `str`
        MMSI as decoded from AIS data.

    Returns
    -------
    `str`
        Country name in the MID Database from ITU.
    """
    mid: str = str(mmsi)[:3]
    country: str = MID_DB.get(mid)
    return country


def get_aton(mmsi: str) -> bool:
    """
    Gets the AIS Aids-to-Navigation (AtoN) status of a given MMSI.

    AIS Aids to Navigation (AtoN):
        AIS used as an aid to navigation uses the format 9192M3I4D5X6X7X8X9
        where the digits 3, 4 and 5 represent the MID and X is any figure
        from 0 to 9. In the United States, these MMSIs are reserved for the
        federal government.
        Src: https://www.navcen.uscg.gov/?pageName=mtmmsi

    :param mmsi: str MMSI as decoded from AIS data.
    :return: bool True if MMSI belongs to an AtoN, otherwise False.
    """
    return str(mmsi)[:2] == "99"


def get_sar(mmsi: str) -> bool:
    """
    Gets the AIS Search-And-Rescue (SAR) status of a given MMSI.

    Search and Rescue Aircraft:
        AIS and DSC equipment used on search and rescue aircraft use the format
        111213M4I5D6X7X8X9 where the digits 4, 5 and 6 represent the MID and X
        is any figure from 0 to 9. In the United States, these MMSIs are
        currently only used by the U.S. Coast Guard.
        Src: https://www.navcen.uscg.gov/?pageName=mtmmsi

    :param mmsi: str MMSI as decoded from AIS data.
    :return:
    """
    sar = False
    _mmsi = str(mmsi)
    if _mmsi[:3] == "111":
        sar = True
    elif _mmsi[:5] in ["30386", "33885"]:  # US Coast Guard
        sar = True
    return sar


def get_crs(mmsi: str) -> bool:
    """
    Gets the CRS status of the vessel based on MMSI.

    :param mmsi: MMSI of the vessel.
    :type mmsi: str
    :returns: True if CRS, False otherwise.
    :rtype: bool
    """
    crs = False
    # Known CRS':
    # 3669145
    # 3669708
    # 3669709
    if str(mmsi)[:4] == "3669" and len(str(mmsi)) == 7:
        crs = True
    elif str(mmsi)[:4] == "003369":
        crs = True
    return crs


def get_shipname(mmsi: str) -> str:
    """
    Gets the ship name from the SHIP_DB based on MMSI.

    :param mmsi: MMSI of the ship.
    :returns: Ship name.
    """
    ship_name: str = ""
    for ship in SHIP_DB:
        if str(ship.get("MMSI")) == str(mmsi):
            ship_name = ship.get("name")
    return ship_name



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Setup for the AIS Cursor-On-Target Gateway.

Source:: https://github.com/ampledata/aiscot
"""

import os
import sys

import setuptools

__title__ = "aiscot"
__version__ = "4.0.0b7"
__author__ = "Greg Albrecht W2GMD <oss@undef.net>"
__copyright__ = "Copyright 2022 Greg Albrecht"
__license__ = "Apache License, Version 2.0"


def publish():
    """Function for publishing package to pypi."""
    if sys.argv[-1] == "publish":
        os.system("python setup.py sdist")
        os.system("twine upload dist/*")
        sys.exit()


publish()


def read_readme(readme_file="README.rst") -> str:
    """Read the contents of the README file for use as a long_description."""
    readme: str = ""
    this_directory = os.path.abspath(os.path.dirname(__file__))
    with open(os.path.join(this_directory, readme_file), encoding="utf-8") as frm:
        readme = frm.read()
    return readme


setuptools.setup(
    version=__version__,
    name=__title__,
    packages=[__title__],
    package_dir={__title__: __title__},
    url=f"https://github.com/ampledata/{__title__}",
    description="AIS Cursor-On-Target Gateway.",
    author="Greg Albrecht",
    author_email="oss@undef.net",
    package_data={"": ["LICENSE", "data/*"]},
    license="Apache License, Version 2.0",
    long_description=read_readme(),
    long_description_content_type="text/x-rst",
    zip_safe=False,
    include_package_data=True,
    install_requires=["pytak", "aiohttp"],
    classifiers=[
        "Programming Language :: Python",
        "License :: OSI Approved :: Apache Software License",
    ],
    keywords=["Sailing", "AIS", "Cursor on Target", "ATAK", "TAK", "CoT"],
    entry_points={"console_scripts": ["aiscot = aiscot.commands:cli"]},
)
